Welcome to skope_rules’ documentation! — skope_rules 0.1.0 documentation

# Welcome to skope_rules’ documentation!

This project can be useful to anyone who wishes to do supervised classification under interpretability constraints: explicit logical rules have to be used for classifying data. This project is particularly suitable for supervised anomaly detection, i.e. imbalanced classification. Application domains include fraud detection, predictive maintenance, intrusion detection, churn detection...

This project comes with a skrules module which contains a single estimator with unit tests, along with examples and benchmarks.

> - API Documentation
> - General examples

See the README for more information.

Index